## Requirements:

* [pytest v5.2.0 or newer](https://docs.pytest.org/en/latest/index.html)

## Installation:

    pip install pytest-percent

## About:

Mark test sessions as successful based on a percentage of passed tests.

## Usage:

    pytest --required-percent=80
  
## Issues

If you encounter any problems, please file an issue along with a detailed description.

## License:

[MIT License](https://github.com/dillonm197/pytest.percent/blob/master/LICENSE)